# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lara_django_projects_grpc/v1/lara_django_projects.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'lara_django_projects_grpc/v1/lara_django_projects.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7lara_django_projects_grpc/v1/lara_django_projects.proto\x12 lara_django.lara_django_projects\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"W\n ExperimentCalendarDestroyRequest\x12\x33\n\x15\x65xperimentcalendar_id\x18\x01 \x01(\tR\x14\x65xperimentcalendarId\"\x1f\n\x1d\x45xperimentCalendarListRequest\"x\n\x1e\x45xperimentCalendarListResponse\x12V\n\x07results\x18\x01 \x03(\x0b\x32<.lara_django.lara_django_projects.ExperimentCalendarResponseR\x07results\"\x88\r\n&ExperimentCalendarPartialUpdateRequest\x12\x38\n\x15\x65xperimentcalendar_id\x18\x01 \x01(\tH\x00R\x14\x65xperimentcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12\x33\n\x16_partial_update_fields\x18\x08 \x03(\tR\x13PartialUpdateFields\x12!\n\x0cname_display\x18\t \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\n \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\x0b \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0c \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\r \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\x0e \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0f \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x10 \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x11 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x12 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x13 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x14 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x15 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x16 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x17 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x18 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x19 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x1a \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1b \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1d \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1e \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1f \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x12#\n\nexperiment\x18  \x01(\tH\x1bR\nexperiment\x88\x01\x01\x42\x18\n\x16_experimentcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vectorB\r\n\x0b_experiment\"\xc6\x0c\n\x19\x45xperimentCalendarRequest\x12\x38\n\x15\x65xperimentcalendar_id\x18\x01 \x01(\tH\x00R\x14\x65xperimentcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12!\n\x0cname_display\x18\x08 \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\t \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\n \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x0c \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\r \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0e \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0f \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x10 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x11 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x12 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x13 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x14 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x15 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x16 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x17 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x18 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x19 \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1a \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1c \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1e \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x12#\n\nexperiment\x18\x1f \x01(\tH\x1bR\nexperiment\x88\x01\x01\x42\x18\n\x16_experimentcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vectorB\r\n\x0b_experiment\"\xc7\x0c\n\x1a\x45xperimentCalendarResponse\x12\x38\n\x15\x65xperimentcalendar_id\x18\x01 \x01(\tH\x00R\x14\x65xperimentcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12!\n\x0cname_display\x18\x08 \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\t \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\n \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x0c \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\r \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0e \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0f \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x10 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x11 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x12 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x13 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x14 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x15 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x16 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x17 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x18 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x19 \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1a \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1c \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1e \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x12#\n\nexperiment\x18\x1f \x01(\tH\x1bR\nexperiment\x88\x01\x01\x42\x18\n\x16_experimentcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vectorB\r\n\x0b_experiment\"X\n!ExperimentCalendarRetrieveRequest\x12\x33\n\x15\x65xperimentcalendar_id\x18\x01 \x01(\tR\x14\x65xperimentcalendarId\"!\n\x1f\x45xperimentCalendarStreamRequest\"?\n\x18\x45xperimentDestroyRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\"\x17\n\x15\x45xperimentListRequest\"h\n\x16\x45xperimentListResponse\x12N\n\x07results\x18\x01 \x03(\x0b\x32\x34.lara_django.lara_django_projects.ExperimentResponseR\x07results\"\xf6\x16\n\x1e\x45xperimentPartialUpdateRequest\x12(\n\rexperiment_id\x18\x01 \x01(\tH\x00R\x0c\x65xperimentId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x30\n\x11\x65xperiment_design\x18\x06 \x01(\tH\x02R\x10\x65xperimentDesign\x88\x01\x01\x12,\n\x0f\x65xperiment_base\x18\x07 \x01(\tH\x03R\x0e\x65xperimentBase\x88\x01\x01\x12\x1b\n\x06status\x18\x08 \x01(\tH\x04R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\t \x01(\tH\x05R\x07outcome\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\n \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18\x0b \x03(\tR\x0b\x65valuations\x12)\n\x10method_instances\x18\x0c \x03(\tR\x0fmethodInstances\x12+\n\x11process_instances\x18\r \x03(\tR\x10processInstances\x12/\n\x13procedure_instances\x18\x0e \x03(\tR\x12procedureInstances\x12/\n\x13substance_instances\x18\x0f \x03(\tR\x12substanceInstances\x12+\n\x11polymer_instances\x18\x10 \x03(\tR\x10polymerInstances\x12+\n\x11mixture_instances\x18\x11 \x03(\tR\x10mixtureInstances\x12-\n\x12organism_instances\x18\x12 \x03(\tR\x11organismInstances\x12%\n\x0epart_instances\x18\x13 \x03(\tR\rpartInstances\x12)\n\x10\x64\x65vice_instances\x18\x14 \x03(\tR\x0f\x64\x65viceInstances\x12\x34\n\x16\x64\x65vice_setup_instances\x18\x15 \x03(\tR\x14\x64\x65viceSetupInstances\x12+\n\x11labware_instances\x18\x16 \x03(\tR\x10labwareInstances\x12\x18\n\x07samples\x18\x17 \x03(\tR\x07samples\x12\x36\n\x14reference_experiment\x18\x18 \x01(\tH\x06R\x13referenceExperiment\x88\x01\x01\x12-\n\x12resources_external\x18\x19 \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\x1a \x03(\tR\x04tags\x12\x33\n\x16_partial_update_fields\x18\x1b \x03(\tR\x13PartialUpdateFields\x12&\n\x0cname_display\x18\x1c \x01(\tH\x07R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x1d \x01(\tH\x08R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x1e \x01(\tH\tR\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1f \x01(\tH\nR\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18  \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18! \x01(\tH\x0cR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\" \x01(\tH\rR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18# \x01(\tH\x0eR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18$ \x01(\tH\x0fR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18% \x01(\tH\x10R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18& \x01(\x02H\x11R\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18\' \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18( \x01(\x0b\x32\x17.google.protobuf.StructH\x13R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18) \x01(\tH\x14R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18* \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18+ \x01(\tH\x16R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18, \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18- \x01(\x0b\x32\x17.google.protobuf.StructH\x18R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18. \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18/ \x01(\x0b\x32\x17.google.protobuf.StructH\x1aR\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18\x30 \x01(\tH\x1bR\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x31 \x01(\tH\x1cR\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18\x32 \x01(\tH\x1dR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x33 \x01(\tH\x1eR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18\x34 \x01(\tH\x1fR\x0csearchVector\x88\x01\x01\x12<\n\nparameters\x18\x35 \x01(\x0b\x32\x17.google.protobuf.StructH R\nparameters\x88\x01\x01\x12\'\n\x0cobservations\x18\x36 \x01(\tH!R\x0cobservations\x88\x01\x01\x12I\n\x11observations_json\x18\x37 \x01(\x0b\x32\x17.google.protobuf.StructH\"R\x10observationsJson\x88\x01\x01\x12\x14\n\x05tasks\x18\x38 \x03(\tR\x05tasksB\x10\n\x0e_experiment_idB\t\n\x07_parentB\x14\n\x12_experiment_designB\x12\n\x10_experiment_baseB\t\n\x07_statusB\n\n\x08_outcomeB\x17\n\x15_reference_experimentB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\r\n\x0b_parametersB\x0f\n\r_observationsB\x14\n\x12_observations_json\"\xb4\x16\n\x11\x45xperimentRequest\x12(\n\rexperiment_id\x18\x01 \x01(\tH\x00R\x0c\x65xperimentId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x30\n\x11\x65xperiment_design\x18\x06 \x01(\tH\x02R\x10\x65xperimentDesign\x88\x01\x01\x12,\n\x0f\x65xperiment_base\x18\x07 \x01(\tH\x03R\x0e\x65xperimentBase\x88\x01\x01\x12\x1b\n\x06status\x18\x08 \x01(\tH\x04R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\t \x01(\tH\x05R\x07outcome\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\n \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18\x0b \x03(\tR\x0b\x65valuations\x12)\n\x10method_instances\x18\x0c \x03(\tR\x0fmethodInstances\x12+\n\x11process_instances\x18\r \x03(\tR\x10processInstances\x12/\n\x13procedure_instances\x18\x0e \x03(\tR\x12procedureInstances\x12/\n\x13substance_instances\x18\x0f \x03(\tR\x12substanceInstances\x12+\n\x11polymer_instances\x18\x10 \x03(\tR\x10polymerInstances\x12+\n\x11mixture_instances\x18\x11 \x03(\tR\x10mixtureInstances\x12-\n\x12organism_instances\x18\x12 \x03(\tR\x11organismInstances\x12%\n\x0epart_instances\x18\x13 \x03(\tR\rpartInstances\x12)\n\x10\x64\x65vice_instances\x18\x14 \x03(\tR\x0f\x64\x65viceInstances\x12\x34\n\x16\x64\x65vice_setup_instances\x18\x15 \x03(\tR\x14\x64\x65viceSetupInstances\x12+\n\x11labware_instances\x18\x16 \x03(\tR\x10labwareInstances\x12\x18\n\x07samples\x18\x17 \x03(\tR\x07samples\x12\x36\n\x14reference_experiment\x18\x18 \x01(\tH\x06R\x13referenceExperiment\x88\x01\x01\x12-\n\x12resources_external\x18\x19 \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\x1a \x03(\tR\x04tags\x12&\n\x0cname_display\x18\x1b \x01(\tH\x07R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x1c \x01(\tH\x08R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x1d \x01(\tH\tR\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1e \x01(\tH\nR\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x1f \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18  \x01(\tH\x0cR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18! \x01(\tH\rR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\" \x01(\tH\x0eR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18# \x01(\tH\x0fR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18$ \x01(\tH\x10R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18% \x01(\x02H\x11R\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18& \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18\' \x01(\x0b\x32\x17.google.protobuf.StructH\x13R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18( \x01(\tH\x14R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18) \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18* \x01(\tH\x16R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18+ \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18, \x01(\x0b\x32\x17.google.protobuf.StructH\x18R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18- \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18. \x01(\x0b\x32\x17.google.protobuf.StructH\x1aR\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18/ \x01(\tH\x1bR\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x30 \x01(\tH\x1cR\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18\x31 \x01(\tH\x1dR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x32 \x01(\tH\x1eR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18\x33 \x01(\tH\x1fR\x0csearchVector\x88\x01\x01\x12<\n\nparameters\x18\x34 \x01(\x0b\x32\x17.google.protobuf.StructH R\nparameters\x88\x01\x01\x12\'\n\x0cobservations\x18\x35 \x01(\tH!R\x0cobservations\x88\x01\x01\x12I\n\x11observations_json\x18\x36 \x01(\x0b\x32\x17.google.protobuf.StructH\"R\x10observationsJson\x88\x01\x01\x12\x14\n\x05tasks\x18\x37 \x03(\tR\x05tasksB\x10\n\x0e_experiment_idB\t\n\x07_parentB\x14\n\x12_experiment_designB\x12\n\x10_experiment_baseB\t\n\x07_statusB\n\n\x08_outcomeB\x17\n\x15_reference_experimentB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\r\n\x0b_parametersB\x0f\n\r_observationsB\x14\n\x12_observations_json\"\xc5\x17\n\x12\x45xperimentResponse\x12(\n\rexperiment_id\x18\x01 \x01(\tH\x00R\x0c\x65xperimentId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x30\n\x11\x65xperiment_design\x18\x06 \x01(\tH\x02R\x10\x65xperimentDesign\x88\x01\x01\x12,\n\x0f\x65xperiment_base\x18\x07 \x01(\tH\x03R\x0e\x65xperimentBase\x88\x01\x01\x12\x1b\n\x06status\x18\x08 \x01(\tH\x04R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\t \x01(\tH\x05R\x07outcome\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\n \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18\x0b \x03(\tR\x0b\x65valuations\x12)\n\x10method_instances\x18\x0c \x03(\tR\x0fmethodInstances\x12+\n\x11process_instances\x18\r \x03(\tR\x10processInstances\x12/\n\x13procedure_instances\x18\x0e \x03(\tR\x12procedureInstances\x12/\n\x13substance_instances\x18\x0f \x03(\tR\x12substanceInstances\x12+\n\x11polymer_instances\x18\x10 \x03(\tR\x10polymerInstances\x12+\n\x11mixture_instances\x18\x11 \x03(\tR\x10mixtureInstances\x12-\n\x12organism_instances\x18\x12 \x03(\tR\x11organismInstances\x12%\n\x0epart_instances\x18\x13 \x03(\tR\rpartInstances\x12)\n\x10\x64\x65vice_instances\x18\x14 \x03(\tR\x0f\x64\x65viceInstances\x12\x34\n\x16\x64\x65vice_setup_instances\x18\x15 \x03(\tR\x14\x64\x65viceSetupInstances\x12+\n\x11labware_instances\x18\x16 \x03(\tR\x10labwareInstances\x12\x18\n\x07samples\x18\x17 \x03(\tR\x07samples\x12\x36\n\x14reference_experiment\x18\x18 \x01(\tH\x06R\x13referenceExperiment\x88\x01\x01\x12-\n\x12resources_external\x18\x19 \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\x1a \x03(\tR\x04tags\x12&\n\x0cname_display\x18\x1b \x01(\tH\x07R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x1c \x01(\tH\x08R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x1d \x01(\tH\tR\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1e \x01(\tH\nR\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x1f \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18  \x01(\tH\x0cR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18! \x01(\tH\rR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\" \x01(\tH\x0eR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18# \x01(\tH\x0fR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18$ \x01(\tH\x10R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18% \x01(\x02H\x11R\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18& \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18\' \x01(\x0b\x32\x17.google.protobuf.StructH\x13R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18( \x01(\tH\x14R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18) \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18* \x01(\tH\x16R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18+ \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18, \x01(\x0b\x32\x17.google.protobuf.StructH\x18R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18- \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18. \x01(\x0b\x32\x17.google.protobuf.StructH\x1aR\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18/ \x01(\tH\x1bR\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x30 \x01(\tH\x1cR\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18\x31 \x01(\tH\x1dR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x32 \x01(\tH\x1eR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18\x33 \x01(\tH\x1fR\x0csearchVector\x88\x01\x01\x12<\n\nparameters\x18\x34 \x01(\x0b\x32\x17.google.protobuf.StructH R\nparameters\x88\x01\x01\x12\'\n\x0cobservations\x18\x35 \x01(\tH!R\x0cobservations\x88\x01\x01\x12I\n\x11observations_json\x18\x36 \x01(\x0b\x32\x17.google.protobuf.StructH\"R\x10observationsJson\x88\x01\x01\x12\x15\n\x03lft\x18\x37 \x01(\x05H#R\x03lft\x88\x01\x01\x12\x17\n\x04rght\x18\x38 \x01(\x05H$R\x04rght\x88\x01\x01\x12\x1c\n\x07tree_id\x18\x39 \x01(\x05H%R\x06treeId\x88\x01\x01\x12\x19\n\x05level\x18: \x01(\x05H&R\x05level\x88\x01\x01\x12\x14\n\x05tasks\x18; \x03(\tR\x05tasksB\x10\n\x0e_experiment_idB\t\n\x07_parentB\x14\n\x12_experiment_designB\x12\n\x10_experiment_baseB\t\n\x07_statusB\n\n\x08_outcomeB\x17\n\x15_reference_experimentB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\r\n\x0b_parametersB\x0f\n\r_observationsB\x14\n\x12_observations_jsonB\x06\n\x04_lftB\x07\n\x05_rghtB\n\n\x08_tree_idB\x08\n\x06_level\"\\\n!ExperimentRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"@\n\x19\x45xperimentRetrieveRequest\x12#\n\rexperiment_id\x18\x01 \x01(\tR\x0c\x65xperimentId\"\x19\n\x17\x45xperimentStreamRequest\"X\n\x1f\x45xperimentsSubsetDestroyRequest\x12\x35\n\x16\x65xperimentselection_id\x18\x01 \x01(\tR\x15\x65xperimentselectionId\"\x1e\n\x1c\x45xperimentsSubsetListRequest\"v\n\x1d\x45xperimentsSubsetListResponse\x12U\n\x07results\x18\x01 \x03(\x0b\x32;.lara_django.lara_django_projects.ExperimentsSubsetResponseR\x07results\"\xa3\x04\n%ExperimentsSubsetPartialUpdateRequest\x12:\n\x16\x65xperimentselection_id\x18\x01 \x01(\tH\x00R\x15\x65xperimentselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12\x33\n\x16_partial_update_fields\x18\x05 \x03(\tR\x13PartialUpdateFields\x12&\n\x0cname_display\x18\x06 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\n \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\x0b \x03(\tR\x04tagsB\x19\n\x17_experimentselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"\xe1\x03\n\x18\x45xperimentsSubsetRequest\x12:\n\x16\x65xperimentselection_id\x18\x01 \x01(\tH\x00R\x15\x65xperimentselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12&\n\x0cname_display\x18\x05 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x08 \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\t \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\n \x03(\tR\x04tagsB\x19\n\x17_experimentselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"\x84\x04\n\x19\x45xperimentsSubsetResponse\x12:\n\x16\x65xperimentselection_id\x18\x01 \x01(\tH\x00R\x15\x65xperimentselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12&\n\x0cname_display\x18\x05 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x08 \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\t \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12 \n\x0b\x65xperiments\x18\x0b \x03(\tR\x0b\x65xperimentsB\x19\n\x17_experimentselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"Y\n ExperimentsSubsetRetrieveRequest\x12\x35\n\x16\x65xperimentselection_id\x18\x01 \x01(\tR\x15\x65xperimentselectionId\" \n\x1e\x45xperimentsSubsetStreamRequest\"]\n\x11\x46ileDownloadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"J\n\x10\x46ileDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"g\n\x0f\x46ileUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"*\n\x0e\x46ileUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"i\n\x12ImageDownloadChunk\x12%\n\x0e\x66ilename_image\x18\x01 \x01(\tR\rfilenameImage\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"K\n\x11ImageDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"h\n\x10ImageUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"+\n\x0fImageUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"N\n\x1dProjectCalendarDestroyRequest\x12-\n\x12projectcalendar_id\x18\x01 \x01(\tR\x11projectcalendarId\"\x1c\n\x1aProjectCalendarListRequest\"r\n\x1bProjectCalendarListResponse\x12S\n\x07results\x18\x01 \x03(\x0b\x32\x39.lara_django.lara_django_projects.ProjectCalendarResponseR\x07results\"\xc8\x0c\n#ProjectCalendarPartialUpdateRequest\x12\x32\n\x12projectcalendar_id\x18\x01 \x01(\tH\x00R\x11projectcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12\x33\n\x16_partial_update_fields\x18\x08 \x03(\tR\x13PartialUpdateFields\x12!\n\x0cname_display\x18\t \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\n \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\x0b \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0c \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\r \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\x0e \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0f \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x10 \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x11 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x12 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x13 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x14 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x15 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x16 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x17 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x18 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x19 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x1a \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1b \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1d \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1e \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1f \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\x15\n\x13_projectcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vector\"\x86\x0c\n\x16ProjectCalendarRequest\x12\x32\n\x12projectcalendar_id\x18\x01 \x01(\tH\x00R\x11projectcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12!\n\x0cname_display\x18\x08 \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\t \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\n \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x0c \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\r \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0e \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0f \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x10 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x11 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x12 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x13 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x14 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x15 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x16 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x17 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x18 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x19 \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1a \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1c \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1e \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\x15\n\x13_projectcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vector\"\x87\x0c\n\x17ProjectCalendarResponse\x12\x32\n\x12projectcalendar_id\x18\x01 \x01(\tH\x00R\x11projectcalendarId\x88\x01\x01\x12\x17\n\x04user\x18\x02 \x01(\tH\x01R\x04user\x88\x01\x01\x12\x1f\n\x08location\x18\x03 \x01(\tH\x02R\x08location\x88\x01\x01\x12%\n\x0bgeolocation\x18\x04 \x01(\tH\x03R\x0bgeolocation\x88\x01\x01\x12\x1d\n\x07project\x18\x05 \x01(\tH\x04R\x07project\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x1c\n\tattendees\x18\x07 \x03(\tR\tattendees\x12!\n\x0cname_display\x18\x08 \x01(\tR\x0bnameDisplay\x12&\n\x0c\x63\x61lendar_url\x18\t \x01(\tH\x05R\x0b\x63\x61lendarUrl\x88\x01\x01\x12\x1d\n\x07summary\x18\n \x01(\tH\x06R\x07summary\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x0c \x01(\tH\x08R\x05\x63olor\x88\x01\x01\x12\x15\n\x03ics\x18\r \x01(\tH\tR\x03ics\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x0e \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0f \x01(\tH\x0bR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x1f\n\x08\x64uration\x18\x10 \x01(\tH\x0cR\x08\x64uration\x88\x01\x01\x12\x1c\n\x07\x61ll_day\x18\x11 \x01(\x08H\rR\x06\x61llDay\x88\x01\x01\x12\x1d\n\x07\x63reated\x18\x12 \x01(\tH\x0eR\x07\x63reated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x13 \x01(\tH\x0fR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12!\n\ttimestamp\x18\x14 \x01(\tH\x10R\ttimestamp\x88\x01\x01\x12*\n\x0e\x63onference_url\x18\x15 \x01(\tH\x11R\rconferenceUrl\x88\x01\x01\x12\x19\n\x05range\x18\x16 \x01(\tH\x12R\x05range\x88\x01\x01\x12\x1d\n\x07related\x18\x17 \x01(\tH\x13R\x07related\x88\x01\x01\x12\x17\n\x04role\x18\x18 \x01(\tH\x14R\x04role\x88\x01\x01\x12\x17\n\x04tzid\x18\x19 \x01(\tH\x15R\x04tzid\x88\x01\x01\x12\"\n\noffset_utc\x18\x1a \x01(\x05H\x16R\toffsetUtc\x88\x01\x01\x12H\n\x11\x61larm_repeat_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0f\x61larmRepeatJson\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x1c \x01(\tH\x18R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x19R\x0f\x65ventRepeatJson\x88\x01\x01\x12(\n\rsearch_vector\x18\x1e \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\x15\n\x13_projectcalendar_idB\x07\n\x05_userB\x0b\n\t_locationB\x0e\n\x0c_geolocationB\n\n\x08_projectB\x0f\n\r_calendar_urlB\n\n\x08_summaryB\x0e\n\x0c_descriptionB\x08\n\x06_colorB\x06\n\x04_icsB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x0b\n\t_durationB\n\n\x08_all_dayB\n\n\x08_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_timestampB\x11\n\x0f_conference_urlB\x08\n\x06_rangeB\n\n\x08_relatedB\x07\n\x05_roleB\x07\n\x05_tzidB\r\n\x0b_offset_utcB\x14\n\x12_alarm_repeat_jsonB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x10\n\x0e_search_vector\"O\n\x1eProjectCalendarRetrieveRequest\x12-\n\x12projectcalendar_id\x18\x01 \x01(\tR\x11projectcalendarId\"\x1e\n\x1cProjectCalendarStreamRequest\"6\n\x15ProjectDestroyRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"\x14\n\x12ProjectListRequest\"b\n\x13ProjectListResponse\x12K\n\x07results\x18\x01 \x03(\x0b\x32\x31.lara_django.lara_django_projects.ProjectResponseR\x07results\"\xf0\x0f\n\x1bProjectPartialUpdateRequest\x12\"\n\nproject_id\x18\x01 \x01(\tH\x00R\tprojectId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x1b\n\x06status\x18\x06 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\x07 \x01(\tH\x03R\x07outcome\x88\x01\x01\x12 \n\x0b\x65xperiments\x18\x08 \x03(\tR\x0b\x65xperiments\x12-\n\x12resources_external\x18\t \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12\x33\n\x16_partial_update_fields\x18\x0b \x03(\tR\x13PartialUpdateFields\x12&\n\x0cname_display\x18\x0c \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\r \x01(\tH\x05R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x0e \x01(\tH\x06R\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x0f \x01(\tH\x07R\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x10 \x01(\x0b\x32\x17.google.protobuf.StructH\x08R\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x11 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x12 \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\x13 \x01(\tH\x0bR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x14 \x01(\tH\x0cR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x15 \x01(\tH\rR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\x16 \x01(\x02H\x0eR\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18\x17 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18\x18 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x19 \x01(\tH\x11R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18\x1a \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18\x1b \x01(\tH\x13R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructH\x14R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18\x1e \x01(\x0b\x32\x17.google.protobuf.StructH\x16R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18\x1f \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18  \x01(\tH\x18R\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18! \x01(\tH\x19R\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18\" \x01(\tH\x1aR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18# \x01(\tH\x1bR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18$ \x01(\tH\x1cR\x0csearchVector\x88\x01\x01\x12&\n\x0cproject_base\x18% \x01(\tH\x1dR\x0bprojectBase\x88\x01\x01\x12\x14\n\x05tasks\x18& \x03(\tR\x05tasks\x12\x12\n\x04\x64\x61ta\x18\' \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18( \x03(\tR\x0b\x65valuationsB\r\n\x0b_project_idB\t\n\x07_parentB\t\n\x07_statusB\n\n\x08_outcomeB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\x0f\n\r_project_base\"\xae\x0f\n\x0eProjectRequest\x12\"\n\nproject_id\x18\x01 \x01(\tH\x00R\tprojectId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x1b\n\x06status\x18\x06 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\x07 \x01(\tH\x03R\x07outcome\x88\x01\x01\x12 \n\x0b\x65xperiments\x18\x08 \x03(\tR\x0b\x65xperiments\x12-\n\x12resources_external\x18\t \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12&\n\x0cname_display\x18\x0b \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x0c \x01(\tH\x05R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\r \x01(\tH\x06R\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x0e \x01(\tH\x07R\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructH\x08R\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x10 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x11 \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\x12 \x01(\tH\x0bR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x13 \x01(\tH\x0cR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x14 \x01(\tH\rR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\x15 \x01(\x02H\x0eR\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18\x16 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18\x17 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x18 \x01(\tH\x11R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18\x1a \x01(\tH\x13R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x14R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x16R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18\x1e \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18\x1f \x01(\tH\x18R\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18  \x01(\tH\x19R\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18! \x01(\tH\x1aR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\" \x01(\tH\x1bR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1cR\x0csearchVector\x88\x01\x01\x12&\n\x0cproject_base\x18$ \x01(\tH\x1dR\x0bprojectBase\x88\x01\x01\x12\x14\n\x05tasks\x18% \x03(\tR\x05tasks\x12\x12\n\x04\x64\x61ta\x18& \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18\' \x03(\tR\x0b\x65valuationsB\r\n\x0b_project_idB\t\n\x07_parentB\t\n\x07_statusB\n\n\x08_outcomeB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\x0f\n\r_project_base\"\xbf\x10\n\x0fProjectResponse\x12\"\n\nproject_id\x18\x01 \x01(\tH\x00R\tprojectId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12\x16\n\x06groups\x18\x04 \x03(\tR\x06groups\x12\x1b\n\x06parent\x18\x05 \x01(\tH\x01R\x06parent\x88\x01\x01\x12\x1b\n\x06status\x18\x06 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1d\n\x07outcome\x18\x07 \x01(\tH\x03R\x07outcome\x88\x01\x01\x12 \n\x0b\x65xperiments\x18\x08 \x03(\tR\x0b\x65xperiments\x12-\n\x12resources_external\x18\t \x03(\tR\x11resourcesExternal\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12&\n\x0cname_display\x18\x0b \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x0c \x01(\tH\x05R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\r \x01(\tH\x06R\x07version\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x0e \x01(\tH\x07R\x05pacId\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructH\x08R\x03\x61\x63l\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x10 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x11 \x01(\tH\nR\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\x12 \x01(\tH\x0bR\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x13 \x01(\tH\x0cR\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x14 \x01(\tH\rR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\x15 \x01(\x02H\x0eR\x08priority\x88\x01\x01\x12\x38\n\x08timeline\x18\x16 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08timeline\x88\x01\x01\x12<\n\nmilestones\x18\x17 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\nmilestones\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x18 \x01(\tH\x11R\x0b\x64\x65scription\x88\x01\x01\x12\x45\n\x0fhypothesis_json\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x12R\x0ehypothesisJson\x88\x01\x01\x12#\n\nhypothesis\x18\x1a \x01(\tH\x13R\nhypothesis\x88\x01\x01\x12\x45\n\x0fobjectives_json\x18\x1b \x01(\x0b\x32\x17.google.protobuf.StructH\x14R\x0eobjectivesJson\x88\x01\x01\x12;\n\nrisks_json\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructH\x15R\trisksJson\x88\x01\x01\x12\x34\n\x06\x62udget\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructH\x16R\x06\x62udget\x88\x01\x01\x12?\n\x0cresults_json\x18\x1e \x01(\x0b\x32\x17.google.protobuf.StructH\x17R\x0bresultsJson\x88\x01\x01\x12\x1d\n\x07remarks\x18\x1f \x01(\tH\x18R\x07remarks\x88\x01\x01\x12\x19\n\x05\x63olor\x18  \x01(\tH\x19R\x05\x63olor\x88\x01\x01\x12\x15\n\x03iri\x18! \x01(\tH\x1aR\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\" \x01(\tH\x1bR\x03pid\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1cR\x0csearchVector\x88\x01\x01\x12\x15\n\x03lft\x18$ \x01(\x05H\x1dR\x03lft\x88\x01\x01\x12\x17\n\x04rght\x18% \x01(\x05H\x1eR\x04rght\x88\x01\x01\x12\x1c\n\x07tree_id\x18& \x01(\x05H\x1fR\x06treeId\x88\x01\x01\x12\x19\n\x05level\x18\' \x01(\x05H R\x05level\x88\x01\x01\x12&\n\x0cproject_base\x18( \x01(\tH!R\x0bprojectBase\x88\x01\x01\x12\x14\n\x05tasks\x18) \x03(\tR\x05tasks\x12\x12\n\x04\x64\x61ta\x18* \x03(\tR\x04\x64\x61ta\x12 \n\x0b\x65valuations\x18+ \x03(\tR\x0b\x65valuationsB\r\n\x0b_project_idB\t\n\x07_parentB\t\n\x07_statusB\n\n\x08_outcomeB\x0f\n\r_name_displayB\x07\n\x05_nameB\n\n\x08_versionB\t\n\x07_pac_idB\x06\n\x04_aclB\x0e\n\x0c_hash_sha256B\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x0b\n\t_timelineB\r\n\x0b_milestonesB\x0e\n\x0c_descriptionB\x12\n\x10_hypothesis_jsonB\r\n\x0b_hypothesisB\x12\n\x10_objectives_jsonB\r\n\x0b_risks_jsonB\t\n\x07_budgetB\x0f\n\r_results_jsonB\n\n\x08_remarksB\x08\n\x06_colorB\x06\n\x04_iriB\x06\n\x04_pidB\x10\n\x0e_search_vectorB\x06\n\x04_lftB\x07\n\x05_rghtB\n\n\x08_tree_idB\x08\n\x06_levelB\x0f\n\r_project_base\"Y\n\x1eProjectRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"7\n\x16ProjectRetrieveRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"\x16\n\x14ProjectStreamRequest\"F\n\x1fProjectSyncStatusDestroyRequest\x12#\n\rsyncstatus_id\x18\x01 \x01(\tR\x0csyncstatusId\"\x1e\n\x1cProjectSyncStatusListRequest\"v\n\x1dProjectSyncStatusListResponse\x12U\n\x07results\x18\x01 \x03(\x0b\x32;.lara_django.lara_django_projects.ProjectSyncStatusResponseR\x07results\"\xb4\x02\n%ProjectSyncStatusPartialUpdateRequest\x12(\n\rsyncstatus_id\x18\x01 \x01(\tH\x00R\x0csyncstatusId\x88\x01\x01\x12\x16\n\x06server\x18\x02 \x01(\tR\x06server\x12\x1a\n\x08projects\x18\x03 \x03(\tR\x08projects\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x33\n\x16_partial_update_fields\x18\x05 \x03(\tR\x13PartialUpdateFields\x12\x35\n\x14\x64\x61tetime_last_synced\x18\x06 \x01(\tH\x01R\x12\x64\x61tetimeLastSynced\x88\x01\x01\x42\x10\n\x0e_syncstatus_idB\x17\n\x15_datetime_last_synced\"\xf2\x01\n\x18ProjectSyncStatusRequest\x12(\n\rsyncstatus_id\x18\x01 \x01(\tH\x00R\x0csyncstatusId\x88\x01\x01\x12\x16\n\x06server\x18\x02 \x01(\tR\x06server\x12\x1a\n\x08projects\x18\x03 \x03(\tR\x08projects\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x35\n\x14\x64\x61tetime_last_synced\x18\x05 \x01(\tH\x01R\x12\x64\x61tetimeLastSynced\x88\x01\x01\x42\x10\n\x0e_syncstatus_idB\x17\n\x15_datetime_last_synced\"\xf3\x01\n\x19ProjectSyncStatusResponse\x12(\n\rsyncstatus_id\x18\x01 \x01(\tH\x00R\x0csyncstatusId\x88\x01\x01\x12\x16\n\x06server\x18\x02 \x01(\tR\x06server\x12\x1a\n\x08projects\x18\x03 \x03(\tR\x08projects\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x35\n\x14\x64\x61tetime_last_synced\x18\x05 \x01(\tH\x01R\x12\x64\x61tetimeLastSynced\x88\x01\x01\x42\x10\n\x0e_syncstatus_idB\x17\n\x15_datetime_last_synced\"G\n ProjectSyncStatusRetrieveRequest\x12#\n\rsyncstatus_id\x18\x01 \x01(\tR\x0csyncstatusId\" \n\x1eProjectSyncStatusStreamRequest\"?\n$ProjectSynchronisationDestroyRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"#\n!ProjectSynchronisationListRequest\"\x80\x01\n\"ProjectSynchronisationListResponse\x12Z\n\x07results\x18\x01 \x03(\x0b\x32@.lara_django.lara_django_projects.ProjectSynchronisationResponseR\x07results\"\xa8\x07\n*ProjectSynchronisationPartialUpdateRequest\x12\x1c\n\x07sync_id\x18\x01 \x01(\tH\x00R\x06syncId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12(\n\rserver_target\x18\x03 \x01(\tH\x01R\x0cserverTarget\x88\x01\x01\x12\x1b\n\x06status\x18\x04 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1a\n\x08projects\x18\x05 \x03(\tR\x08projects\x12\x33\n\x16_partial_update_fields\x18\x06 \x03(\tR\x13PartialUpdateFields\x12\x17\n\x04name\x18\x07 \x01(\tH\x03R\x04name\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x08 \x01(\tH\x04R\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\t \x01(\tH\x05R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x17\n\x04mode\x18\n \x01(\tH\x06R\x04mode\x88\x01\x01\x12(\n\rupdate_policy\x18\x0b \x01(\tH\x07R\x0cupdatePolicy\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x0c \x01(\tH\x08R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\r \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x0f\x65ventRepeatJson\x88\x01\x01\x12=\n\x0b\x63onfig_json\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\nR\nconfigJson\x88\x01\x01\x12\x30\n\x04logs\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x04logs\x88\x01\x01\x12\x1e\n\x08log_file\x18\x10 \x01(\tH\x0cR\x07logFile\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x11 \x01(\tH\rR\x0b\x64\x65scription\x88\x01\x01\x42\n\n\x08_sync_idB\x10\n\x0e_server_targetB\t\n\x07_statusB\x07\n\x05_nameB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x07\n\x05_modeB\x10\n\x0e_update_policyB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x0e\n\x0c_config_jsonB\x07\n\x05_logsB\x0b\n\t_log_fileB\x0e\n\x0c_description\"\xe6\x06\n\x1dProjectSynchronisationRequest\x12\x1c\n\x07sync_id\x18\x01 \x01(\tH\x00R\x06syncId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12(\n\rserver_target\x18\x03 \x01(\tH\x01R\x0cserverTarget\x88\x01\x01\x12\x1b\n\x06status\x18\x04 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1a\n\x08projects\x18\x05 \x03(\tR\x08projects\x12\x17\n\x04name\x18\x06 \x01(\tH\x03R\x04name\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x07 \x01(\tH\x04R\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x08 \x01(\tH\x05R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x17\n\x04mode\x18\t \x01(\tH\x06R\x04mode\x88\x01\x01\x12(\n\rupdate_policy\x18\n \x01(\tH\x07R\x0cupdatePolicy\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x0b \x01(\tH\x08R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x0f\x65ventRepeatJson\x88\x01\x01\x12=\n\x0b\x63onfig_json\x18\r \x01(\x0b\x32\x17.google.protobuf.StructH\nR\nconfigJson\x88\x01\x01\x12\x30\n\x04logs\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x04logs\x88\x01\x01\x12\x1e\n\x08log_file\x18\x0f \x01(\tH\x0cR\x07logFile\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\rR\x0b\x64\x65scription\x88\x01\x01\x42\n\n\x08_sync_idB\x10\n\x0e_server_targetB\t\n\x07_statusB\x07\n\x05_nameB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x07\n\x05_modeB\x10\n\x0e_update_policyB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x0e\n\x0c_config_jsonB\x07\n\x05_logsB\x0b\n\t_log_fileB\x0e\n\x0c_description\"\xe7\x06\n\x1eProjectSynchronisationResponse\x12\x1c\n\x07sync_id\x18\x01 \x01(\tH\x00R\x06syncId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12(\n\rserver_target\x18\x03 \x01(\tH\x01R\x0cserverTarget\x88\x01\x01\x12\x1b\n\x06status\x18\x04 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x1a\n\x08projects\x18\x05 \x03(\tR\x08projects\x12\x17\n\x04name\x18\x06 \x01(\tH\x03R\x04name\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\x07 \x01(\tH\x04R\rdatetimeStart\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x08 \x01(\tH\x05R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x17\n\x04mode\x18\t \x01(\tH\x06R\x04mode\x88\x01\x01\x12(\n\rupdate_policy\x18\n \x01(\tH\x07R\x0cupdatePolicy\x88\x01\x01\x12&\n\x0c\x65vent_repeat\x18\x0b \x01(\tH\x08R\x0b\x65ventRepeat\x88\x01\x01\x12H\n\x11\x65vent_repeat_json\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x0f\x65ventRepeatJson\x88\x01\x01\x12=\n\x0b\x63onfig_json\x18\r \x01(\x0b\x32\x17.google.protobuf.StructH\nR\nconfigJson\x88\x01\x01\x12\x30\n\x04logs\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x04logs\x88\x01\x01\x12\x1e\n\x08log_file\x18\x0f \x01(\tH\x0cR\x07logFile\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\rR\x0b\x64\x65scription\x88\x01\x01\x42\n\n\x08_sync_idB\x10\n\x0e_server_targetB\t\n\x07_statusB\x07\n\x05_nameB\x11\n\x0f_datetime_startB\x0f\n\r_datetime_endB\x07\n\x05_modeB\x10\n\x0e_update_policyB\x0f\n\r_event_repeatB\x14\n\x12_event_repeat_jsonB\x0e\n\x0c_config_jsonB\x07\n\x05_logsB\x0b\n\t_log_fileB\x0e\n\x0c_description\"@\n%ProjectSynchronisationRetrieveRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"%\n#ProjectSynchronisationStreamRequest\"O\n\x1cProjectsSubsetDestroyRequest\x12/\n\x13projectselection_id\x18\x01 \x01(\tR\x12projectselectionId\"\x1b\n\x19ProjectsSubsetListRequest\"p\n\x1aProjectsSubsetListResponse\x12R\n\x07results\x18\x01 \x03(\x0b\x32\x38.lara_django.lara_django_projects.ProjectsSubsetResponseR\x07results\"\x97\x04\n\"ProjectsSubsetPartialUpdateRequest\x12\x34\n\x13projectselection_id\x18\x01 \x01(\tH\x00R\x12projectselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12\x33\n\x16_partial_update_fields\x18\x05 \x03(\tR\x13PartialUpdateFields\x12&\n\x0cname_display\x18\x06 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\n \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\x0b \x03(\tR\x04tagsB\x16\n\x14_projectselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"\xd5\x03\n\x15ProjectsSubsetRequest\x12\x34\n\x13projectselection_id\x18\x01 \x01(\tH\x00R\x12projectselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12&\n\x0cname_display\x18\x05 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x08 \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\t \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\n \x03(\tR\x04tagsB\x16\n\x14_projectselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"\xf2\x03\n\x16ProjectsSubsetResponse\x12\x34\n\x13projectselection_id\x18\x01 \x01(\tH\x00R\x12projectselectionId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x16\n\x06\x65ntity\x18\x03 \x01(\tR\x06\x65ntity\x12%\n\x0eselected_items\x18\x04 \x03(\tR\rselectedItems\x12&\n\x0cname_display\x18\x05 \x01(\tH\x01R\x0bnameDisplay\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x08 \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x19\n\x05group\x18\t \x01(\tH\x04R\x05group\x88\x01\x01\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\x12\x1a\n\x08projects\x18\x0b \x03(\tR\x08projectsB\x16\n\x14_projectselection_idB\x0f\n\r_name_displayB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x08\n\x06_group\"P\n\x1dProjectsSubsetRetrieveRequest\x12/\n\x13projectselection_id\x18\x01 \x01(\tR\x12projectselectionId\"\x1d\n\x1bProjectsSubsetStreamRequest\"-\n\x12TaskDestroyRequest\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\"\x11\n\x0fTaskListRequest\"\\\n\x10TaskListResponse\x12H\n\x07results\x18\x01 \x03(\x0b\x32..lara_django.lara_django_projects.TaskResponseR\x07results\"\x94\x06\n\x18TaskPartialUpdateRequest\x12\x1c\n\x07task_id\x18\x01 \x01(\tH\x00R\x06taskId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12 \n\ttask_base\x18\x04 \x01(\tH\x01R\x08taskBase\x88\x01\x01\x12\x1b\n\x06status\x18\x05 \x01(\tH\x02R\x06status\x88\x01\x01\x12\x33\n\x16_partial_update_fields\x18\x06 \x03(\tR\x13PartialUpdateFields\x12&\n\x0cname_display\x18\x07 \x01(\tH\x03R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x08 \x01(\tH\x04R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\n \x01(\tH\x06R\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\x0b \x01(\tH\x07R\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0c \x01(\tH\x08R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\r \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\x0e \x01(\x02H\nR\x08priority\x88\x01\x01\x12(\n\rsearch_vector\x18\x0f \x01(\tH\x0bR\x0csearchVector\x88\x01\x01\x42\n\n\x08_task_idB\x0c\n\n_task_baseB\t\n\x07_statusB\x0f\n\r_name_displayB\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x10\n\x0e_search_vector\"\xd2\x05\n\x0bTaskRequest\x12\x1c\n\x07task_id\x18\x01 \x01(\tH\x00R\x06taskId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12 \n\ttask_base\x18\x04 \x01(\tH\x01R\x08taskBase\x88\x01\x01\x12\x1b\n\x06status\x18\x05 \x01(\tH\x02R\x06status\x88\x01\x01\x12&\n\x0cname_display\x18\x06 \x01(\tH\x03R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x07 \x01(\tH\x04R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\t \x01(\tH\x06R\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\n \x01(\tH\x07R\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0b \x01(\tH\x08R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0c \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\r \x01(\x02H\nR\x08priority\x88\x01\x01\x12(\n\rsearch_vector\x18\x0e \x01(\tH\x0bR\x0csearchVector\x88\x01\x01\x42\n\n\x08_task_idB\x0c\n\n_task_baseB\t\n\x07_statusB\x0f\n\r_name_displayB\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x10\n\x0e_search_vector\"\xd3\x05\n\x0cTaskResponse\x12\x1c\n\x07task_id\x18\x01 \x01(\tH\x00R\x06taskId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x1a\n\x08\x65ntities\x18\x03 \x03(\tR\x08\x65ntities\x12 \n\ttask_base\x18\x04 \x01(\tH\x01R\x08taskBase\x88\x01\x01\x12\x1b\n\x06status\x18\x05 \x01(\tH\x02R\x06status\x88\x01\x01\x12&\n\x0cname_display\x18\x06 \x01(\tH\x03R\x0bnameDisplay\x88\x01\x01\x12\x17\n\x04name\x18\x07 \x01(\tH\x04R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0e\x64\x61tetime_start\x18\t \x01(\tH\x06R\rdatetimeStart\x88\x01\x01\x12*\n\x0e\x64\x61tetime_added\x18\n \x01(\tH\x07R\rdatetimeAdded\x88\x01\x01\x12&\n\x0c\x64\x61tetime_end\x18\x0b \x01(\tH\x08R\x0b\x64\x61tetimeEnd\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0c \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x1f\n\x08priority\x18\r \x01(\x02H\nR\x08priority\x88\x01\x01\x12(\n\rsearch_vector\x18\x0e \x01(\tH\x0bR\x0csearchVector\x88\x01\x01\x42\n\n\x08_task_idB\x0c\n\n_task_baseB\t\n\x07_statusB\x0f\n\r_name_displayB\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x11\n\x0f_datetime_startB\x11\n\x0f_datetime_addedB\x0f\n\r_datetime_endB\x19\n\x17_datetime_last_modifiedB\x0b\n\t_priorityB\x10\n\x0e_search_vector\"V\n\x1bTaskRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\".\n\x13TaskRetrieveRequest\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\"\x13\n\x11TaskStreamRequest2\xe3\x07\n\x1c\x45xperimentCalendarController\x12\x85\x01\n\x06\x43reate\x12;.lara_django.lara_django_projects.ExperimentCalendarRequest\x1a<.lara_django.lara_django_projects.ExperimentCalendarResponse\"\x00\x12g\n\x07\x44\x65stroy\x12\x42.lara_django.lara_django_projects.ExperimentCalendarDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x8b\x01\n\x04List\x12?.lara_django.lara_django_projects.ExperimentCalendarListRequest\x1a@.lara_django.lara_django_projects.ExperimentCalendarListResponse\"\x00\x12\x99\x01\n\rPartialUpdate\x12H.lara_django.lara_django_projects.ExperimentCalendarPartialUpdateRequest\x1a<.lara_django.lara_django_projects.ExperimentCalendarResponse\"\x00\x12\x8f\x01\n\x08Retrieve\x12\x43.lara_django.lara_django_projects.ExperimentCalendarRetrieveRequest\x1a<.lara_django.lara_django_projects.ExperimentCalendarResponse\"\x00\x12\x8d\x01\n\x06Stream\x12\x41.lara_django.lara_django_projects.ExperimentCalendarStreamRequest\x1a<.lara_django.lara_django_projects.ExperimentCalendarResponse\"\x00\x30\x01\x12\x85\x01\n\x06Update\x12;.lara_django.lara_django_projects.ExperimentCalendarRequest\x1a<.lara_django.lara_django_projects.ExperimentCalendarResponse\"\x00\x32\xf5\x0b\n\x14\x45xperimentController\x12u\n\x06\x43reate\x12\x33.lara_django.lara_django_projects.ExperimentRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x12_\n\x07\x44\x65stroy\x12:.lara_django.lara_django_projects.ExperimentDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x0c\x44ownloadFile\x12\x32.lara_django.lara_django_projects.FileDownloadInfo\x1a\x33.lara_django.lara_django_projects.FileDownloadChunk\"\x00\x30\x01\x12~\n\rDownloadImage\x12\x33.lara_django.lara_django_projects.ImageDownloadInfo\x1a\x34.lara_django.lara_django_projects.ImageDownloadChunk\"\x00\x30\x01\x12{\n\x04List\x12\x37.lara_django.lara_django_projects.ExperimentListRequest\x1a\x38.lara_django.lara_django_projects.ExperimentListResponse\"\x00\x12\x89\x01\n\rPartialUpdate\x12@.lara_django.lara_django_projects.ExperimentPartialUpdateRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x12\x7f\n\x08Retrieve\x12;.lara_django.lara_django_projects.ExperimentRetrieveRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x12\x96\x01\n\x17RetrieveByNameNamespace\x12\x43.lara_django.lara_django_projects.ExperimentRetrieveByNameNSRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x12}\n\x06Stream\x12\x39.lara_django.lara_django_projects.ExperimentStreamRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x30\x01\x12u\n\x06Update\x12\x33.lara_django.lara_django_projects.ExperimentRequest\x1a\x34.lara_django.lara_django_projects.ExperimentResponse\"\x00\x12u\n\nUploadFile\x12\x31.lara_django.lara_django_projects.FileUploadChunk\x1a\x30.lara_django.lara_django_projects.FileUploadInfo\"\x00(\x01\x12x\n\x0bUploadImage\x12\x32.lara_django.lara_django_projects.ImageUploadChunk\x1a\x31.lara_django.lara_django_projects.ImageUploadInfo\"\x00(\x01\x32\xd5\x07\n\x1b\x45xperimentsSubsetController\x12\x83\x01\n\x06\x43reate\x12:.lara_django.lara_django_projects.ExperimentsSubsetRequest\x1a;.lara_django.lara_django_projects.ExperimentsSubsetResponse\"\x00\x12\x66\n\x07\x44\x65stroy\x12\x41.lara_django.lara_django_projects.ExperimentsSubsetDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x89\x01\n\x04List\x12>.lara_django.lara_django_projects.ExperimentsSubsetListRequest\x1a?.lara_django.lara_django_projects.ExperimentsSubsetListResponse\"\x00\x12\x97\x01\n\rPartialUpdate\x12G.lara_django.lara_django_projects.ExperimentsSubsetPartialUpdateRequest\x1a;.lara_django.lara_django_projects.ExperimentsSubsetResponse\"\x00\x12\x8d\x01\n\x08Retrieve\x12\x42.lara_django.lara_django_projects.ExperimentsSubsetRetrieveRequest\x1a;.lara_django.lara_django_projects.ExperimentsSubsetResponse\"\x00\x12\x8b\x01\n\x06Stream\x12@.lara_django.lara_django_projects.ExperimentsSubsetStreamRequest\x1a;.lara_django.lara_django_projects.ExperimentsSubsetResponse\"\x00\x30\x01\x12\x83\x01\n\x06Update\x12:.lara_django.lara_django_projects.ExperimentsSubsetRequest\x1a;.lara_django.lara_django_projects.ExperimentsSubsetResponse\"\x00\x32\xb7\x07\n\x19ProjectCalendarController\x12\x7f\n\x06\x43reate\x12\x38.lara_django.lara_django_projects.ProjectCalendarRequest\x1a\x39.lara_django.lara_django_projects.ProjectCalendarResponse\"\x00\x12\x64\n\x07\x44\x65stroy\x12?.lara_django.lara_django_projects.ProjectCalendarDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x85\x01\n\x04List\x12<.lara_django.lara_django_projects.ProjectCalendarListRequest\x1a=.lara_django.lara_django_projects.ProjectCalendarListResponse\"\x00\x12\x93\x01\n\rPartialUpdate\x12\x45.lara_django.lara_django_projects.ProjectCalendarPartialUpdateRequest\x1a\x39.lara_django.lara_django_projects.ProjectCalendarResponse\"\x00\x12\x89\x01\n\x08Retrieve\x12@.lara_django.lara_django_projects.ProjectCalendarRetrieveRequest\x1a\x39.lara_django.lara_django_projects.ProjectCalendarResponse\"\x00\x12\x87\x01\n\x06Stream\x12>.lara_django.lara_django_projects.ProjectCalendarStreamRequest\x1a\x39.lara_django.lara_django_projects.ProjectCalendarResponse\"\x00\x30\x01\x12\x7f\n\x06Update\x12\x38.lara_django.lara_django_projects.ProjectCalendarRequest\x1a\x39.lara_django.lara_django_projects.ProjectCalendarResponse\"\x00\x32\xc5\x0b\n\x11ProjectController\x12o\n\x06\x43reate\x12\x30.lara_django.lara_django_projects.ProjectRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x12\\\n\x07\x44\x65stroy\x12\x37.lara_django.lara_django_projects.ProjectDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x0c\x44ownloadFile\x12\x32.lara_django.lara_django_projects.FileDownloadInfo\x1a\x33.lara_django.lara_django_projects.FileDownloadChunk\"\x00\x30\x01\x12~\n\rDownloadImage\x12\x33.lara_django.lara_django_projects.ImageDownloadInfo\x1a\x34.lara_django.lara_django_projects.ImageDownloadChunk\"\x00\x30\x01\x12u\n\x04List\x12\x34.lara_django.lara_django_projects.ProjectListRequest\x1a\x35.lara_django.lara_django_projects.ProjectListResponse\"\x00\x12\x83\x01\n\rPartialUpdate\x12=.lara_django.lara_django_projects.ProjectPartialUpdateRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x12y\n\x08Retrieve\x12\x38.lara_django.lara_django_projects.ProjectRetrieveRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x12\x90\x01\n\x17RetrieveByNameNamespace\x12@.lara_django.lara_django_projects.ProjectRetrieveByNameNSRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x12w\n\x06Stream\x12\x36.lara_django.lara_django_projects.ProjectStreamRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x30\x01\x12o\n\x06Update\x12\x30.lara_django.lara_django_projects.ProjectRequest\x1a\x31.lara_django.lara_django_projects.ProjectResponse\"\x00\x12u\n\nUploadFile\x12\x31.lara_django.lara_django_projects.FileUploadChunk\x1a\x30.lara_django.lara_django_projects.FileUploadInfo\"\x00(\x01\x12x\n\x0bUploadImage\x12\x32.lara_django.lara_django_projects.ImageUploadChunk\x1a\x31.lara_django.lara_django_projects.ImageUploadInfo\"\x00(\x01\x32\xd5\x07\n\x1bProjectSyncStatusController\x12\x83\x01\n\x06\x43reate\x12:.lara_django.lara_django_projects.ProjectSyncStatusRequest\x1a;.lara_django.lara_django_projects.ProjectSyncStatusResponse\"\x00\x12\x66\n\x07\x44\x65stroy\x12\x41.lara_django.lara_django_projects.ProjectSyncStatusDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x89\x01\n\x04List\x12>.lara_django.lara_django_projects.ProjectSyncStatusListRequest\x1a?.lara_django.lara_django_projects.ProjectSyncStatusListResponse\"\x00\x12\x97\x01\n\rPartialUpdate\x12G.lara_django.lara_django_projects.ProjectSyncStatusPartialUpdateRequest\x1a;.lara_django.lara_django_projects.ProjectSyncStatusResponse\"\x00\x12\x8d\x01\n\x08Retrieve\x12\x42.lara_django.lara_django_projects.ProjectSyncStatusRetrieveRequest\x1a;.lara_django.lara_django_projects.ProjectSyncStatusResponse\"\x00\x12\x8b\x01\n\x06Stream\x12@.lara_django.lara_django_projects.ProjectSyncStatusStreamRequest\x1a;.lara_django.lara_django_projects.ProjectSyncStatusResponse\"\x00\x30\x01\x12\x83\x01\n\x06Update\x12:.lara_django.lara_django_projects.ProjectSyncStatusRequest\x1a;.lara_django.lara_django_projects.ProjectSyncStatusResponse\"\x00\x32\x9b\x08\n ProjectSynchronisationController\x12\x8d\x01\n\x06\x43reate\x12?.lara_django.lara_django_projects.ProjectSynchronisationRequest\x1a@.lara_django.lara_django_projects.ProjectSynchronisationResponse\"\x00\x12k\n\x07\x44\x65stroy\x12\x46.lara_django.lara_django_projects.ProjectSynchronisationDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x93\x01\n\x04List\x12\x43.lara_django.lara_django_projects.ProjectSynchronisationListRequest\x1a\x44.lara_django.lara_django_projects.ProjectSynchronisationListResponse\"\x00\x12\xa1\x01\n\rPartialUpdate\x12L.lara_django.lara_django_projects.ProjectSynchronisationPartialUpdateRequest\x1a@.lara_django.lara_django_projects.ProjectSynchronisationResponse\"\x00\x12\x97\x01\n\x08Retrieve\x12G.lara_django.lara_django_projects.ProjectSynchronisationRetrieveRequest\x1a@.lara_django.lara_django_projects.ProjectSynchronisationResponse\"\x00\x12\x95\x01\n\x06Stream\x12\x45.lara_django.lara_django_projects.ProjectSynchronisationStreamRequest\x1a@.lara_django.lara_django_projects.ProjectSynchronisationResponse\"\x00\x30\x01\x12\x8d\x01\n\x06Update\x12?.lara_django.lara_django_projects.ProjectSynchronisationRequest\x1a@.lara_django.lara_django_projects.ProjectSynchronisationResponse\"\x00\x32\xa9\x07\n\x18ProjectsSubsetController\x12}\n\x06\x43reate\x12\x37.lara_django.lara_django_projects.ProjectsSubsetRequest\x1a\x38.lara_django.lara_django_projects.ProjectsSubsetResponse\"\x00\x12\x63\n\x07\x44\x65stroy\x12>.lara_django.lara_django_projects.ProjectsSubsetDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x83\x01\n\x04List\x12;.lara_django.lara_django_projects.ProjectsSubsetListRequest\x1a<.lara_django.lara_django_projects.ProjectsSubsetListResponse\"\x00\x12\x91\x01\n\rPartialUpdate\x12\x44.lara_django.lara_django_projects.ProjectsSubsetPartialUpdateRequest\x1a\x38.lara_django.lara_django_projects.ProjectsSubsetResponse\"\x00\x12\x87\x01\n\x08Retrieve\x12?.lara_django.lara_django_projects.ProjectsSubsetRetrieveRequest\x1a\x38.lara_django.lara_django_projects.ProjectsSubsetResponse\"\x00\x12\x85\x01\n\x06Stream\x12=.lara_django.lara_django_projects.ProjectsSubsetStreamRequest\x1a\x38.lara_django.lara_django_projects.ProjectsSubsetResponse\"\x00\x30\x01\x12}\n\x06Update\x12\x37.lara_django.lara_django_projects.ProjectsSubsetRequest\x1a\x38.lara_django.lara_django_projects.ProjectsSubsetResponse\"\x00\x32\x94\x0b\n\x0eTaskController\x12i\n\x06\x43reate\x12-.lara_django.lara_django_projects.TaskRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x12Y\n\x07\x44\x65stroy\x12\x34.lara_django.lara_django_projects.TaskDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x0c\x44ownloadFile\x12\x32.lara_django.lara_django_projects.FileDownloadInfo\x1a\x33.lara_django.lara_django_projects.FileDownloadChunk\"\x00\x30\x01\x12~\n\rDownloadImage\x12\x33.lara_django.lara_django_projects.ImageDownloadInfo\x1a\x34.lara_django.lara_django_projects.ImageDownloadChunk\"\x00\x30\x01\x12o\n\x04List\x12\x31.lara_django.lara_django_projects.TaskListRequest\x1a\x32.lara_django.lara_django_projects.TaskListResponse\"\x00\x12}\n\rPartialUpdate\x12:.lara_django.lara_django_projects.TaskPartialUpdateRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x12s\n\x08Retrieve\x12\x35.lara_django.lara_django_projects.TaskRetrieveRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x12\x8a\x01\n\x17RetrieveByNameNamespace\x12=.lara_django.lara_django_projects.TaskRetrieveByNameNSRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x12q\n\x06Stream\x12\x33.lara_django.lara_django_projects.TaskStreamRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x30\x01\x12i\n\x06Update\x12-.lara_django.lara_django_projects.TaskRequest\x1a..lara_django.lara_django_projects.TaskResponse\"\x00\x12u\n\nUploadFile\x12\x31.lara_django.lara_django_projects.FileUploadChunk\x1a\x30.lara_django.lara_django_projects.FileUploadInfo\"\x00(\x01\x12x\n\x0bUploadImage\x12\x32.lara_django.lara_django_projects.ImageUploadChunk\x1a\x31.lara_django.lara_django_projects.ImageUploadInfo\"\x00(\x01\x42\xa1\x02\n$com.lara_django.lara_django_projectsB\x17LaraDjangoProjectsProtoP\x01ZKgitlab.com/larasuite/lara-django-projects/grpc/lara_django_projects_grpc/v1\xa2\x02\x03LLX\xaa\x02\x1dLaraDjango.LaraDjangoProjects\xca\x02\x1dLaraDjango\\LaraDjangoProjects\xe2\x02)LaraDjango\\LaraDjangoProjects\\GPBMetadata\xea\x02\x1eLaraDjango::LaraDjangoProjectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lara_django_projects_grpc.v1.lara_django_projects_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.lara_django.lara_django_projectsB\027LaraDjangoProjectsProtoP\001ZKgitlab.com/larasuite/lara-django-projects/grpc/lara_django_projects_grpc/v1\242\002\003LLX\252\002\035LaraDjango.LaraDjangoProjects\312\002\035LaraDjango\\LaraDjangoProjects\342\002)LaraDjango\\LaraDjangoProjects\\GPBMetadata\352\002\036LaraDjango::LaraDjangoProjects'
  _globals['_EXPERIMENTCALENDARDESTROYREQUEST']._serialized_start=152
  _globals['_EXPERIMENTCALENDARDESTROYREQUEST']._serialized_end=239
  _globals['_EXPERIMENTCALENDARLISTREQUEST']._serialized_start=241
  _globals['_EXPERIMENTCALENDARLISTREQUEST']._serialized_end=272
  _globals['_EXPERIMENTCALENDARLISTRESPONSE']._serialized_start=274
  _globals['_EXPERIMENTCALENDARLISTRESPONSE']._serialized_end=394
  _globals['_EXPERIMENTCALENDARPARTIALUPDATEREQUEST']._serialized_start=397
  _globals['_EXPERIMENTCALENDARPARTIALUPDATEREQUEST']._serialized_end=2069
  _globals['_EXPERIMENTCALENDARREQUEST']._serialized_start=2072
  _globals['_EXPERIMENTCALENDARREQUEST']._serialized_end=3678
  _globals['_EXPERIMENTCALENDARRESPONSE']._serialized_start=3681
  _globals['_EXPERIMENTCALENDARRESPONSE']._serialized_end=5288
  _globals['_EXPERIMENTCALENDARRETRIEVEREQUEST']._serialized_start=5290
  _globals['_EXPERIMENTCALENDARRETRIEVEREQUEST']._serialized_end=5378
  _globals['_EXPERIMENTCALENDARSTREAMREQUEST']._serialized_start=5380
  _globals['_EXPERIMENTCALENDARSTREAMREQUEST']._serialized_end=5413
  _globals['_EXPERIMENTDESTROYREQUEST']._serialized_start=5415
  _globals['_EXPERIMENTDESTROYREQUEST']._serialized_end=5478
  _globals['_EXPERIMENTLISTREQUEST']._serialized_start=5480
  _globals['_EXPERIMENTLISTREQUEST']._serialized_end=5503
  _globals['_EXPERIMENTLISTRESPONSE']._serialized_start=5505
  _globals['_EXPERIMENTLISTRESPONSE']._serialized_end=5609
  _globals['_EXPERIMENTPARTIALUPDATEREQUEST']._serialized_start=5612
  _globals['_EXPERIMENTPARTIALUPDATEREQUEST']._serialized_end=8546
  _globals['_EXPERIMENTREQUEST']._serialized_start=8549
  _globals['_EXPERIMENTREQUEST']._serialized_end=11417
  _globals['_EXPERIMENTRESPONSE']._serialized_start=11420
  _globals['_EXPERIMENTRESPONSE']._serialized_end=14433
  _globals['_EXPERIMENTRETRIEVEBYNAMENSREQUEST']._serialized_start=14435
  _globals['_EXPERIMENTRETRIEVEBYNAMENSREQUEST']._serialized_end=14527
  _globals['_EXPERIMENTRETRIEVEREQUEST']._serialized_start=14529
  _globals['_EXPERIMENTRETRIEVEREQUEST']._serialized_end=14593
  _globals['_EXPERIMENTSTREAMREQUEST']._serialized_start=14595
  _globals['_EXPERIMENTSTREAMREQUEST']._serialized_end=14620
  _globals['_EXPERIMENTSSUBSETDESTROYREQUEST']._serialized_start=14622
  _globals['_EXPERIMENTSSUBSETDESTROYREQUEST']._serialized_end=14710
  _globals['_EXPERIMENTSSUBSETLISTREQUEST']._serialized_start=14712
  _globals['_EXPERIMENTSSUBSETLISTREQUEST']._serialized_end=14742
  _globals['_EXPERIMENTSSUBSETLISTRESPONSE']._serialized_start=14744
  _globals['_EXPERIMENTSSUBSETLISTRESPONSE']._serialized_end=14862
  _globals['_EXPERIMENTSSUBSETPARTIALUPDATEREQUEST']._serialized_start=14865
  _globals['_EXPERIMENTSSUBSETPARTIALUPDATEREQUEST']._serialized_end=15412
  _globals['_EXPERIMENTSSUBSETREQUEST']._serialized_start=15415
  _globals['_EXPERIMENTSSUBSETREQUEST']._serialized_end=15896
  _globals['_EXPERIMENTSSUBSETRESPONSE']._serialized_start=15899
  _globals['_EXPERIMENTSSUBSETRESPONSE']._serialized_end=16415
  _globals['_EXPERIMENTSSUBSETRETRIEVEREQUEST']._serialized_start=16417
  _globals['_EXPERIMENTSSUBSETRETRIEVEREQUEST']._serialized_end=16506
  _globals['_EXPERIMENTSSUBSETSTREAMREQUEST']._serialized_start=16508
  _globals['_EXPERIMENTSSUBSETSTREAMREQUEST']._serialized_end=16540
  _globals['_FILEDOWNLOADCHUNK']._serialized_start=16542
  _globals['_FILEDOWNLOADCHUNK']._serialized_end=16635
  _globals['_FILEDOWNLOADINFO']._serialized_start=16637
  _globals['_FILEDOWNLOADINFO']._serialized_end=16711
  _globals['_FILEUPLOADCHUNK']._serialized_start=16713
  _globals['_FILEUPLOADCHUNK']._serialized_end=16816
  _globals['_FILEUPLOADINFO']._serialized_start=16818
  _globals['_FILEUPLOADINFO']._serialized_end=16860
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_start=16862
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_end=16967
  _globals['_IMAGEDOWNLOADINFO']._serialized_start=16969
  _globals['_IMAGEDOWNLOADINFO']._serialized_end=17044
  _globals['_IMAGEUPLOADCHUNK']._serialized_start=17046
  _globals['_IMAGEUPLOADCHUNK']._serialized_end=17150
  _globals['_IMAGEUPLOADINFO']._serialized_start=17152
  _globals['_IMAGEUPLOADINFO']._serialized_end=17195
  _globals['_PROJECTCALENDARDESTROYREQUEST']._serialized_start=17197
  _globals['_PROJECTCALENDARDESTROYREQUEST']._serialized_end=17275
  _globals['_PROJECTCALENDARLISTREQUEST']._serialized_start=17277
  _globals['_PROJECTCALENDARLISTREQUEST']._serialized_end=17305
  _globals['_PROJECTCALENDARLISTRESPONSE']._serialized_start=17307
  _globals['_PROJECTCALENDARLISTRESPONSE']._serialized_end=17421
  _globals['_PROJECTCALENDARPARTIALUPDATEREQUEST']._serialized_start=17424
  _globals['_PROJECTCALENDARPARTIALUPDATEREQUEST']._serialized_end=19032
  _globals['_PROJECTCALENDARREQUEST']._serialized_start=19035
  _globals['_PROJECTCALENDARREQUEST']._serialized_end=20577
  _globals['_PROJECTCALENDARRESPONSE']._serialized_start=20580
  _globals['_PROJECTCALENDARRESPONSE']._serialized_end=22123
  _globals['_PROJECTCALENDARRETRIEVEREQUEST']._serialized_start=22125
  _globals['_PROJECTCALENDARRETRIEVEREQUEST']._serialized_end=22204
  _globals['_PROJECTCALENDARSTREAMREQUEST']._serialized_start=22206
  _globals['_PROJECTCALENDARSTREAMREQUEST']._serialized_end=22236
  _globals['_PROJECTDESTROYREQUEST']._serialized_start=22238
  _globals['_PROJECTDESTROYREQUEST']._serialized_end=22292
  _globals['_PROJECTLISTREQUEST']._serialized_start=22294
  _globals['_PROJECTLISTREQUEST']._serialized_end=22314
  _globals['_PROJECTLISTRESPONSE']._serialized_start=22316
  _globals['_PROJECTLISTRESPONSE']._serialized_end=22414
  _globals['_PROJECTPARTIALUPDATEREQUEST']._serialized_start=22417
  _globals['_PROJECTPARTIALUPDATEREQUEST']._serialized_end=24449
  _globals['_PROJECTREQUEST']._serialized_start=24452
  _globals['_PROJECTREQUEST']._serialized_end=26418
  _globals['_PROJECTRESPONSE']._serialized_start=26421
  _globals['_PROJECTRESPONSE']._serialized_end=28532
  _globals['_PROJECTRETRIEVEBYNAMENSREQUEST']._serialized_start=28534
  _globals['_PROJECTRETRIEVEBYNAMENSREQUEST']._serialized_end=28623
  _globals['_PROJECTRETRIEVEREQUEST']._serialized_start=28625
  _globals['_PROJECTRETRIEVEREQUEST']._serialized_end=28680
  _globals['_PROJECTSTREAMREQUEST']._serialized_start=28682
  _globals['_PROJECTSTREAMREQUEST']._serialized_end=28704
  _globals['_PROJECTSYNCSTATUSDESTROYREQUEST']._serialized_start=28706
  _globals['_PROJECTSYNCSTATUSDESTROYREQUEST']._serialized_end=28776
  _globals['_PROJECTSYNCSTATUSLISTREQUEST']._serialized_start=28778
  _globals['_PROJECTSYNCSTATUSLISTREQUEST']._serialized_end=28808
  _globals['_PROJECTSYNCSTATUSLISTRESPONSE']._serialized_start=28810
  _globals['_PROJECTSYNCSTATUSLISTRESPONSE']._serialized_end=28928
  _globals['_PROJECTSYNCSTATUSPARTIALUPDATEREQUEST']._serialized_start=28931
  _globals['_PROJECTSYNCSTATUSPARTIALUPDATEREQUEST']._serialized_end=29239
  _globals['_PROJECTSYNCSTATUSREQUEST']._serialized_start=29242
  _globals['_PROJECTSYNCSTATUSREQUEST']._serialized_end=29484
  _globals['_PROJECTSYNCSTATUSRESPONSE']._serialized_start=29487
  _globals['_PROJECTSYNCSTATUSRESPONSE']._serialized_end=29730
  _globals['_PROJECTSYNCSTATUSRETRIEVEREQUEST']._serialized_start=29732
  _globals['_PROJECTSYNCSTATUSRETRIEVEREQUEST']._serialized_end=29803
  _globals['_PROJECTSYNCSTATUSSTREAMREQUEST']._serialized_start=29805
  _globals['_PROJECTSYNCSTATUSSTREAMREQUEST']._serialized_end=29837
  _globals['_PROJECTSYNCHRONISATIONDESTROYREQUEST']._serialized_start=29839
  _globals['_PROJECTSYNCHRONISATIONDESTROYREQUEST']._serialized_end=29902
  _globals['_PROJECTSYNCHRONISATIONLISTREQUEST']._serialized_start=29904
  _globals['_PROJECTSYNCHRONISATIONLISTREQUEST']._serialized_end=29939
  _globals['_PROJECTSYNCHRONISATIONLISTRESPONSE']._serialized_start=29942
  _globals['_PROJECTSYNCHRONISATIONLISTRESPONSE']._serialized_end=30070
  _globals['_PROJECTSYNCHRONISATIONPARTIALUPDATEREQUEST']._serialized_start=30073
  _globals['_PROJECTSYNCHRONISATIONPARTIALUPDATEREQUEST']._serialized_end=31009
  _globals['_PROJECTSYNCHRONISATIONREQUEST']._serialized_start=31012
  _globals['_PROJECTSYNCHRONISATIONREQUEST']._serialized_end=31882
  _globals['_PROJECTSYNCHRONISATIONRESPONSE']._serialized_start=31885
  _globals['_PROJECTSYNCHRONISATIONRESPONSE']._serialized_end=32756
  _globals['_PROJECTSYNCHRONISATIONRETRIEVEREQUEST']._serialized_start=32758
  _globals['_PROJECTSYNCHRONISATIONRETRIEVEREQUEST']._serialized_end=32822
  _globals['_PROJECTSYNCHRONISATIONSTREAMREQUEST']._serialized_start=32824
  _globals['_PROJECTSYNCHRONISATIONSTREAMREQUEST']._serialized_end=32861
  _globals['_PROJECTSSUBSETDESTROYREQUEST']._serialized_start=32863
  _globals['_PROJECTSSUBSETDESTROYREQUEST']._serialized_end=32942
  _globals['_PROJECTSSUBSETLISTREQUEST']._serialized_start=32944
  _globals['_PROJECTSSUBSETLISTREQUEST']._serialized_end=32971
  _globals['_PROJECTSSUBSETLISTRESPONSE']._serialized_start=32973
  _globals['_PROJECTSSUBSETLISTRESPONSE']._serialized_end=33085
  _globals['_PROJECTSSUBSETPARTIALUPDATEREQUEST']._serialized_start=33088
  _globals['_PROJECTSSUBSETPARTIALUPDATEREQUEST']._serialized_end=33623
  _globals['_PROJECTSSUBSETREQUEST']._serialized_start=33626
  _globals['_PROJECTSSUBSETREQUEST']._serialized_end=34095
  _globals['_PROJECTSSUBSETRESPONSE']._serialized_start=34098
  _globals['_PROJECTSSUBSETRESPONSE']._serialized_end=34596
  _globals['_PROJECTSSUBSETRETRIEVEREQUEST']._serialized_start=34598
  _globals['_PROJECTSSUBSETRETRIEVEREQUEST']._serialized_end=34678
  _globals['_PROJECTSSUBSETSTREAMREQUEST']._serialized_start=34680
  _globals['_PROJECTSSUBSETSTREAMREQUEST']._serialized_end=34709
  _globals['_TASKDESTROYREQUEST']._serialized_start=34711
  _globals['_TASKDESTROYREQUEST']._serialized_end=34756
  _globals['_TASKLISTREQUEST']._serialized_start=34758
  _globals['_TASKLISTREQUEST']._serialized_end=34775
  _globals['_TASKLISTRESPONSE']._serialized_start=34777
  _globals['_TASKLISTRESPONSE']._serialized_end=34869
  _globals['_TASKPARTIALUPDATEREQUEST']._serialized_start=34872
  _globals['_TASKPARTIALUPDATEREQUEST']._serialized_end=35660
  _globals['_TASKREQUEST']._serialized_start=35663
  _globals['_TASKREQUEST']._serialized_end=36385
  _globals['_TASKRESPONSE']._serialized_start=36388
  _globals['_TASKRESPONSE']._serialized_end=37111
  _globals['_TASKRETRIEVEBYNAMENSREQUEST']._serialized_start=37113
  _globals['_TASKRETRIEVEBYNAMENSREQUEST']._serialized_end=37199
  _globals['_TASKRETRIEVEREQUEST']._serialized_start=37201
  _globals['_TASKRETRIEVEREQUEST']._serialized_end=37247
  _globals['_TASKSTREAMREQUEST']._serialized_start=37249
  _globals['_TASKSTREAMREQUEST']._serialized_end=37268
  _globals['_EXPERIMENTCALENDARCONTROLLER']._serialized_start=37271
  _globals['_EXPERIMENTCALENDARCONTROLLER']._serialized_end=38266
  _globals['_EXPERIMENTCONTROLLER']._serialized_start=38269
  _globals['_EXPERIMENTCONTROLLER']._serialized_end=39794
  _globals['_EXPERIMENTSSUBSETCONTROLLER']._serialized_start=39797
  _globals['_EXPERIMENTSSUBSETCONTROLLER']._serialized_end=40778
  _globals['_PROJECTCALENDARCONTROLLER']._serialized_start=40781
  _globals['_PROJECTCALENDARCONTROLLER']._serialized_end=41732
  _globals['_PROJECTCONTROLLER']._serialized_start=41735
  _globals['_PROJECTCONTROLLER']._serialized_end=43212
  _globals['_PROJECTSYNCSTATUSCONTROLLER']._serialized_start=43215
  _globals['_PROJECTSYNCSTATUSCONTROLLER']._serialized_end=44196
  _globals['_PROJECTSYNCHRONISATIONCONTROLLER']._serialized_start=44199
  _globals['_PROJECTSYNCHRONISATIONCONTROLLER']._serialized_end=45250
  _globals['_PROJECTSSUBSETCONTROLLER']._serialized_start=45253
  _globals['_PROJECTSSUBSETCONTROLLER']._serialized_end=46190
  _globals['_TASKCONTROLLER']._serialized_start=46193
  _globals['_TASKCONTROLLER']._serialized_end=47621
# @@protoc_insertion_point(module_scope)
